@@ -65,7 +65,7 @@ KParameterEditor::KParameterEditor( QList<Value> *l, QWidget *parent )
 	connect(buttonBox, &QDialogButtonBox::rejected, this, &KParameterEditor::reject);
 	mainLayout->addWidget(buttonBox);
 
-	mainLayout->setMargin( 0 );
+	mainLayout->setContentsMargins( 0, 0, 0, 0 );
 	
 	m_mainWidget->cmdNew->setIcon( QIcon::fromTheme("document-new" ) );
 	m_mainWidget->cmdDelete->setIcon( QIcon::fromTheme("edit-delete" ) );
@@ -79,7 +79,7 @@ KParameterEditor::KParameterEditor( QList<Value> *l, QWidget *parent )
 	connect(m_mainWidget->value, &EquationEdit::upPressed, this, &KParameterEditor::prev);
 	connect(m_mainWidget->value, &EquationEdit::downPressed, this, &KParameterEditor::next);
 	
-	foreach ( const Value &v, *m_parameter )
+	for ( const Value &v : qAsConst(*m_parameter) )
 		m_mainWidget->list->addItem( v.expression() );
 	
 	connect(m_mainWidget->cmdNew, &QPushButton::clicked, this, &KParameterEditor::cmdNew_clicked);
